==> dolmen.content-0.3.tar.gz: dolmen.content-0.3/src/dolmen/content/base.py <==
# -*- coding: utf-8 -*-

from zope.formlib.form import Fields
from dolmen.content import interfaces, require
from dolmen.content.directives import schema
from grokcore.component import baseclass
from grokcore.content import Model, Container, OrderedContainer
from zope.dublincore.property import DCProperty
from zope.interface import implements


class BaseContent(Model):
    baseclass()
    schema(interfaces.IBaseContent)
    require("zope.ManageContent")

    title = DCProperty('title')

    def __init__(self, **kwargs):
        Model.__init__(self)
        if kwargs:
            schemas = schema.bind().get(self)
            ifields = Fields(*schemas)
            for key, value in kwargs.items():
                ifield = ifields.get(key)
                if ifield is None:
                    continue
                field = ifield.field.bind(self)
                field.validate(value)
                field.set(self, value)


class Container(BaseContent, Container):
    """A dolmen folderish content type.
    """
    baseclass()
    implements(interfaces.IContainer)

    def __init__(self, **kwargs):
        Container.__init__(self)
        BaseContent.__init__(self, **kwargs)


class OrderedContainer(BaseContent, OrderedContainer):
    """A dolmen folderish content type with ordered keys.
    """
    baseclass()
    implements(interfaces.IOrderedContainer)

    def __init__(self, **kwargs):
        OrderedContainer.__init__(self)
        BaseContent.__init__(self, **kwargs)


class Content(BaseContent):
    """A dolmen content type.
    """
    baseclass()
    implements(interfaces.IContent)

==> dolmen.content-0.4.tar.gz: dolmen.content-0.4/src/dolmen/content/base.py <==
# -*- coding: utf-8 -*-

import grokcore.content
from zope.formlib.form import Fields
from dolmen.content import interfaces, require
from dolmen.content.directives import schema
from grokcore.component import baseclass
from zope.dublincore.property import DCProperty
from zope.interface import implements


class BaseContent(grokcore.content.Model):
    baseclass()
    schema(interfaces.IBaseContent)
    require("zope.ManageContent")

    title = DCProperty('title')

    def __init__(self, **kwargs):
        grokcore.content.Model.__init__(self)
        if kwargs:
            schemas = schema.bind().get(self)
            ifields = Fields(*schemas)
            for key, value in kwargs.items():
                ifield = ifields.get(key)
                if ifield is None:
                    continue
                field = ifield.field.bind(self)
                field.validate(value)
                field.set(self, value)


class Container(BaseContent, grokcore.content.Container):
    """A dolmen folderish content type.
    """
    baseclass()
    implements(interfaces.IContainer)

    def __init__(self, **kwargs):
        grokcore.content.Container.__init__(self)
        BaseContent.__init__(self, **kwargs)


class OrderedContainer(BaseContent, grokcore.content.OrderedContainer):
    """A dolmen folderish content type with ordered keys.
    """
    baseclass()
    implements(interfaces.IOrderedContainer)

    def __init__(self, **kwargs):
        grokcore.content.OrderedContainer.__init__(self)
        BaseContent.__init__(self, **kwargs)


class Content(BaseContent):
    """A dolmen content type.
    """
    baseclass()
    implements(interfaces.IContent)
